@@ -45,10 +45,12 @@
 #define PKG_PRINT_ERRORS		(1<<26)
 #define PKG_SIMULATE			(1<<27)
 #define PKG_NO_CACHE			(1<<28)
+#define PKG_PROVIDES			(1<<29)
+#define PKG_VALIDATE			(1<<30)
 
 static unsigned int global_traverse_flags = PKGF_NONE;
 
-static int want_flags;
+static uint64_t want_flags;
 static int maximum_traverse_depth = 2000;
 
 static char *want_variable = NULL;
@@ -495,7 +497,7 @@ static void
 about(void)
 {
 	printf("%s %s%s\n", PACKAGE_NAME, PACKAGE_VERSION, HAVE_STRICT_MODE ? " [strict]" : " [pkg-config " PKG_PKGCONFIG_VERSION_EQUIV " compatible]");
-	printf("Copyright (c) 2011, 2012, 2013 pkgconf authors (see AUTHORS in documentation directory).\n\n");
+	printf("Copyright (c) 2011, 2012, 2013, 2014, 2015 pkgconf authors (see AUTHORS in documentation directory).\n\n");
 	printf("Permission to use, copy, modify, and/or distribute this software for any\n");
 	printf("purpose with or without fee is hereby granted, provided that the above\n");
 	printf("copyright notice and this permission notice appear in all copies.\n\n");
@@ -537,6 +539,7 @@ usage(void)
 	printf("                                    (for static linking)\n");
 	printf("  --env-only                        look only for package entries in PKG_CONFIG_PATH\n");
 	printf("  --ignore-conflicts                ignore 'conflicts' rules in modules\n");
+	printf("  --validate                        validate specific .pc files for correctness\n");
 
 	printf("\nquerying specific pkg-config database fields:\n\n");
 
@@ -611,7 +614,9 @@ main(int argc, char *argv[])
 		{ "list-all", no_argument, &want_flags, PKG_LIST|PKG_PRINT_ERRORS, },
 		{ "simulate", no_argument, &want_flags, PKG_SIMULATE, },
 		{ "no-cache", no_argument, &want_flags, PKG_NO_CACHE, },
+		{ "print-provides", no_argument, &want_flags, PKG_PROVIDES, },
 		{ "debug", no_argument, &want_flags, 0, },
+		{ "validate", no_argument, NULL, 0 },
 		{ NULL, 0, NULL, 0 }
 	};
 
@@ -867,6 +872,9 @@ main(int argc, char *argv[])
 		goto out;
 	}
 
+	if ((want_flags & PKG_VALIDATE) == PKG_VALIDATE)
+		return 0;
+
 	if ((want_flags & PKG_UNINSTALLED) == PKG_UNINSTALLED)
 	{
 		ret = EXIT_FAILURE;
@@ -874,6 +882,14 @@ main(int argc, char *argv[])
 		goto out;
 	}
 
+	if ((want_flags & PKG_PROVIDES) == PKG_PROVIDES)
+	{
+		fprintf(stderr, "pkgconf: warning: --print-provides requested which is intentionally unimplemented, along with\n");
+		fprintf(stderr, "  the rest of the Provides system.  The Provides system is broken by design and requires loading every\n");
+		fprintf(stderr, "  package module to calculate the dependency graph.  In practice, there are no consumers of this system\n");
+		fprintf(stderr, "  so it will remain unimplemented until such time that something actually uses it.\n");
+	}
+
 	if ((want_flags & PKG_DIGRAPH) == PKG_DIGRAPH)
 	{
 		want_flags &= ~(PKG_CFLAGS|PKG_LIBS);
